@@ -92,11 +92,12 @@
 #' @template reference-morey
 #'
 #' @examples
+#' if (.Platform$OS.type != "windows" || .Platform$r_arch != "i386") {
 #' if (!exists("example_model")) example(example_model)
 #' posterior_interval(example_model)
 #' posterior_interval(example_model, regex_pars = "herd")
 #' posterior_interval(example_model, pars = "period2", prob = 0.5)
-#'
+#' }
 posterior_interval.stanreg <-
   function(object,
            prob = 0.9,
@@ -104,8 +105,6 @@ posterior_interval.stanreg <-
            pars = NULL,
            regex_pars = NULL,
            ...) {
-    if (used.optimizing(object))
-      STOP_not_optimizing("posterior_interval")
     if (!identical(type, "central"))
       stop("Currently the only option for 'type' is 'central'.",
            call. = FALSE)
