@@ -15,23 +15,17 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-.onLoad <- function(libname, pkgname) { # nocov start
+.onLoad <- function(libname, pkgname) {
   modules <- paste0("stan_fit4", names(stanmodels), "_mod")
   for (m in modules) loadModule(m, what = TRUE)
-} # nocov end
+}
 
 .onAttach <- function(...) {
-  rstanarmLib <- dirname(system.file(package = "rstanarm"))
-  pkgdesc <- suppressWarnings(utils::packageDescription("rstanarm", lib.loc = rstanarmLib))
-  if (length(pkgdesc) > 1) {
-    builddate <- gsub(';.*$', '', pkgdesc$Packaged)
-    packageStartupMessage(paste("rstanarm (Version ", pkgdesc$Version, ", packaged: ", builddate, ")", sep = ""))
-  }
-  packageStartupMessage("- Do not expect the default priors to remain the same in future rstanarm versions.")
-  packageStartupMessage("Thus, R scripts should specify priors explicitly, even if they are just the defaults.")
+  ver <- utils::packageVersion("rstanarm")
+  packageStartupMessage("This is rstanarm version ", ver)
+  packageStartupMessage("- See https://mc-stan.org/rstanarm/articles/priors for changes to default priors!")
+  packageStartupMessage("- Default priors may change, so it's safest to specify priors, even if equivalent to the defaults.")
   packageStartupMessage("- For execution on a local, multicore CPU with excess RAM we recommend calling")
-  packageStartupMessage("options(mc.cores = parallel::detectCores())")
-  packageStartupMessage("- Plotting theme set to bayesplot::theme_default().")
-  ggplot2::theme_set(bayesplot::theme_default())
+  packageStartupMessage("  options(mc.cores = parallel::detectCores())")
 }
 
